@@ -164,7 +164,7 @@ class RpcExchangerClient:
             raise ChatAlreadyJoinedError()
         if not await self._rpc.chat_join(chat_id=id, user_id=self._uid):
             raise UnknownError()
-        self._pubsub.subscribe(f"messages:{id}")
+        await self._pubsub.subscribe(f"messages:{id}")
         self._chat_list.add(id)
     
     async def chat_quit(self, id: int) -> None:
@@ -173,7 +173,7 @@ class RpcExchangerClient:
             raise ChatNotJoinedError()
         if not await self._rpc.chat_quit(chat_id=id, user_id=self._uid):
             raise UnknownError()
-        self._pubsub.unsubscribe(f"messages:{id}")
+        await self._pubsub.unsubscribe(f"messages:{id}")
         self._chat_list.remove(id)
 
     async def __aenter__(self) -> RpcExchangerClient:
